==> pyconnectwise-0.4.4-py3-none-any.whl: pyconnectwise/endpoints/manage/SalesStagesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SalesStagesCountEndpoint import SalesStagesCountEndpoint
from pyconnectwise.endpoints.manage.SalesStagesIdEndpoint import SalesStagesIdEndpoint
from pyconnectwise.endpoints.manage.SalesStagesInfoEndpoint import SalesStagesInfoEndpoint
from pyconnectwise.models.base.message_model import GenericMessageModel
from pyconnectwise.models.manage import OpportunityStage
from pyconnectwise.responses.paginated_response import PaginatedResponse


class SalesStagesEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "stages", parent_endpoint=parent_endpoint)

        self.info = self._register_child_endpoint(SalesStagesInfoEndpoint(client, parent_endpoint=self))
        self.count = self._register_child_endpoint(SalesStagesCountEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> SalesStagesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SalesStagesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            SalesStagesIdEndpoint: The initialized SalesStagesIdEndpoint object.
        """
        child = SalesStagesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[OpportunityStage]:
        """
        Performs a GET request against the /sales/stages endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[OpportunityStage]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            OpportunityStage,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[OpportunityStage]:
        """
        Performs a GET request against the /sales/stages endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[OpportunityStage]: The parsed response data.
        """
        return self._parse_many(OpportunityStage, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> OpportunityStage:
        """
        Performs a POST request against the /sales/stages endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            OpportunityStage: The parsed response data.
        """
        return self._parse_one(OpportunityStage, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.6.0.1-py3-none-any.whl: pyconnectwise/endpoints/manage/SalesStagesEndpoint.py <==
from typing import TYPE_CHECKING

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SalesStagesCountEndpoint import SalesStagesCountEndpoint
from pyconnectwise.endpoints.manage.SalesStagesIdEndpoint import SalesStagesIdEndpoint
from pyconnectwise.endpoints.manage.SalesStagesInfoEndpoint import SalesStagesInfoEndpoint
from pyconnectwise.interfaces import IGettable, IPaginateable, IPostable
from pyconnectwise.models.manage import OpportunityStage
from pyconnectwise.responses.paginated_response import PaginatedResponse
from pyconnectwise.types import JSON, ConnectWiseManageRequestParams

if TYPE_CHECKING:
    from pyconnectwise.clients.connectwise_client import ConnectWiseClient


class SalesStagesEndpoint(
    ConnectWiseEndpoint,
    IGettable[list[OpportunityStage], ConnectWiseManageRequestParams],
    IPostable[OpportunityStage, ConnectWiseManageRequestParams],
    IPaginateable[OpportunityStage, ConnectWiseManageRequestParams],
):
    def __init__(self, client: "ConnectWiseClient", parent_endpoint: ConnectWiseEndpoint = None) -> None:
        ConnectWiseEndpoint.__init__(self, client, "stages", parent_endpoint=parent_endpoint)
        IGettable.__init__(self, list[OpportunityStage])
        IPostable.__init__(self, OpportunityStage)
        IPaginateable.__init__(self, OpportunityStage)

        self.count = self._register_child_endpoint(SalesStagesCountEndpoint(client, parent_endpoint=self))
        self.info = self._register_child_endpoint(SalesStagesInfoEndpoint(client, parent_endpoint=self))

    def id(self, _id: int) -> SalesStagesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SalesStagesIdEndpoint object to move down the chain.

        Parameters:
            _id (int): The ID to set.
        Returns:
            SalesStagesIdEndpoint: The initialized SalesStagesIdEndpoint object.
        """
        child = SalesStagesIdEndpoint(self.client, parent_endpoint=self)
        child._id = _id
        return child

    def paginated(
        self, page: int, page_size: int, params: ConnectWiseManageRequestParams | None = None
    ) -> PaginatedResponse[OpportunityStage]:
        """
        Performs a GET request against the /sales/stages endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[OpportunityStage]: The initialized PaginatedResponse object.
        """
        if params:
            params["page"] = page
            params["pageSize"] = page_size
        else:
            params = {"page": page, "pageSize": page_size}
        return PaginatedResponse(
            super()._make_request("GET", params=params), OpportunityStage, self, page, page_size, params
        )

    def get(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> list[OpportunityStage]:
        """
        Performs a GET request against the /sales/stages endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[OpportunityStage]: The parsed response data.
        """
        return self._parse_many(OpportunityStage, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None) -> OpportunityStage:
        """
        Performs a POST request against the /sales/stages endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            OpportunityStage: The parsed response data.
        """
        return self._parse_one(OpportunityStage, super()._make_request("POST", data=data, params=params).json())
